@@ -1,7 +1,7 @@
 package Number::Closest::XS;
 use strict;
 use warnings;
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 my $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -18,7 +18,7 @@ Number::Closest::XS - find numbers closest to a given
 
 =head1 VERSION
 
-This document describes Number::Closest::XS version 0.08
+This document describes Number::Closest::XS version 0.09
 
 =head1 SYNOPSIS
 
@@ -37,7 +37,9 @@ given.
 
 selects from the I<@list> up to I<$amount> numbers closest to the I<$num>. If
 I<$amount> is not specified, is assumed to be 1.  Returns reference to the
-array containing found numbers sorted by the distance from the I<$num>.
+array containing found numbers sorted by the distance from the I<$num>. The
+sort is stable, so the numbers that have the same distance to the C<$num> will
+be present in the result in the same order as in the C<@list>.
 Distance between C<$num> and C<$x> computed as C<abs($num - $x)>.
 
 =head2 find_closest_numbers_around($num, \@list, [$amount])
